@@ -123,7 +123,8 @@ var TorBirdyPrefs = {
   "security.enable_ssl3": false,
   // Thunderbird 23.0 uses the following preference.
   // https://bugs.torproject.org/11253
-  "security.tls.version.min": 1,
+  // March 2017: See https://bugs.torproject.org/20751
+  "security.tls.version.min": 3,
   "security.tls.version.max": 3,
   // Display a dialog warning the user when entering an insecure site from a secure one.
   "security.warn_entering_weak": true,
@@ -272,10 +273,10 @@ var TorBirdyPrefs = {
                                               // We want to force UTF-8 everywhere
                                               "--display-charset utf-8 " +
                                               // We want to ensure that Enigmail is proxy aware even when it runs gpg in a shell
-                                              "--keyserver-options http-proxy=socks5h://127.0.0.1:9150 ",
+                                              "--keyserver-options http-proxy=socks5h://127.0.0.1:9050 ",
                                             
-  // The default key server should be a hidden service and this is the only known one (it's part of the normal SKS network)
-  "extensions.enigmail.keyserver": "hkp://qdigse2yzvuglcix.onion",
+  // The default key server should be a hidden service; use the Tor OnionBalance hidden service pool (https://sks-keyservers.net/overview-of-pools.php#pool_tor)
+  "extensions.enigmail.keyserver": "hkp://jirk5u4osbsr34t5.onion",
   // Force GnuPG to use SHA512.
   "extensions.enigmail.mimeHashAlgorithm": 5,
 
@@ -597,9 +598,6 @@ TorBirdy.prototype = {
       var accounts = this.acctMgr.accounts;
 
       var allAccounts = [];
-      // To maintain compatibility between Gecko 17+ and Gecko < 17, find out
-      // which version we are on.
-
       var accountLength = accounts.length;
       for (let i = 0; i < accountLength; i++) {
         var account = accounts.queryElementAt(i, Ci.nsIMsgAccount);
@@ -699,7 +697,7 @@ TorBirdy.prototype = {
         ["mail.smtpserver.%smtp%.try_ssl", 3], // SSL/TLS
       ];
       for (let i = 0; i < smtpAccounts.length; i++) {
-        for each (var [pref_template, value] in smtpPrefs) {
+        for (var [pref_template, value] of smtpPrefs) {
           let pref = pref_template.replace("%smtp%", smtpAccounts[i]);
           if (this.prefs.prefHasUserValue(pref)) {
             let currentPref = Preferences.get(pref);
